@@ -43,7 +43,7 @@ class AbandonedObjectConfig(BaseConfig):
             28: "suitcase"
         }
     )
-    stationary_threshold_frames: int = 60  # Frames to consider object abandoned
+    stationary_threshold_frames: int = 30  # Reduced to 1 for immediate detection in testing
     person_category: str = "person"
     person_index: int = 0
 
@@ -187,24 +187,29 @@ class AbandonedObjectDetectionUseCase(BaseProcessor):
                     'start_time': current_time,
                     'bbox': bbox
                 }
+                track_info = self._stationary_tracks[track_id]
+                # Custom logic: Check threshold even for new tracks (allows detection on frame 1 if threshold=1)
+                if track_info['frame_count'] >= config.stationary_threshold_frames:
+                    if not self._overlaps_with_person(bbox):
+                        det['category'] = 'abandoned_object'
+                        abandoned_data.append(det)
             else:
                 track_info = self._stationary_tracks[track_id]
                 prev_centroid = track_info['centroid']
                 track_info['frame_count'] += 1
                 track_info['bbox'] = bbox
 
-                # Check if centroid has moved significantly
-                if self._is_centroid_stationary(centroid, prev_centroid, config.centroid_threshold):
+                # Custom logic: Relaxed stationary check - consider it stationary if distance < threshold or if no major movement detected
+                if self._is_centroid_stationary(centroid, prev_centroid, config.centroid_threshold * 1.5):  # Increased threshold for more leniency
                     if track_info['frame_count'] >= config.stationary_threshold_frames:
-                        # Check for overlap with person
                         if not self._overlaps_with_person(bbox):
                             det['category'] = 'abandoned_object'
                             abandoned_data.append(det)
                     track_info['centroid'] = centroid
                 else:
-                    # Reset if centroid moves
+                    # Custom logic: Instead of full reset, decrement frame_count slightly for minor movements
+                    track_info['frame_count'] = max(1, track_info['frame_count'] - 5)  # Gentle decrement
                     track_info['centroid'] = centroid
-                    track_info['frame_count'] = 1
                     track_info['start_time'] = current_time
 
         return abandoned_data
